class Course:
	
	def __init__(self, name, duration, link):
	
		self.name = name
		self.duration = duration
		self.link = link
	
	def __repr__(self):
		return f"{self.name}, {self.duration}, {self.link}"
		
courses = [
	Course("Introducción a linux", 15, "X"),
	Course("Personalización de Linux", 3, "Y"),
	Course("Introducción al Hacking", 53, "Z")
]


def list_courses():

	for course in courses:
		print(course)

def search_course_by_name(name):

	for course in courses:

		if course.name == name:
			return course
	return None



from setuptools import setup, find_packages

with open("README.md", 'r', encoding="utf-8") as fh:
	long_description = fh.read()

setup(
	name="em1l10",
	version="0.1.0",
	packages=find_packages(),
	install_requires=[],
	author="Emilio Arteaga",
	description="First Package",
	long_description=long_description,
	long_description_content_type="text/markdown",
	url="https://google.es",
)
